Documentation
¶
Index ¶
- func AreProfilesFriends(ctx context.Context, db QueryRower, dialect string, profileID1 int, ...) (bool, error)
- func AttachGalleryImageToProfile(ctx context.Context, db Execer, dialect string, imageID int, profileID int) error
- func ClearProfileImageByImageID(ctx context.Context, db Execer, dialect string, imageID int) error
- func CountSubscriptionBenefactorsBySubscriptionID(ctx context.Context, db QueryRower, dialect string, subscriptionID int) (int, error)
- func CountUnseenNotificationsByProfile(ctx context.Context, db QueryRower, dialect string, profileID int) (int, error)
- func DeleteImageByID(ctx context.Context, db Execer, dialect string, imageID int) error
- func DeletePasswordTokensByUserID(ctx context.Context, db Execer, dialect string, userID int) error
- func DeleteSubscriptionByID(ctx context.Context, db Execer, dialect string, subscriptionID int) error
- func DeleteUserByProfileID(ctx context.Context, db Execer, dialect string, profileID int) error
- func GetPasswordTokenHash(ctx context.Context, db QueryRower, dialect string, userID int, tokenID int, ...) (string, error)
- func GetProfileFullyOnboardedByUserID(ctx context.Context, db QueryRower, dialect string, userID int) (bool, error)
- func GetProfileImageIDByProfileID(ctx context.Context, db QueryRower, dialect string, profileID int) (sql.NullInt64, error)
- func GetProfileThumbnailObjectKeyByUserID(ctx context.Context, db QueryRower, dialect string, userID int) (string, error)
- func GetUserDisplayNameByUserID(ctx context.Context, db QueryRower, dialect string, userID int) (string, error)
- func ImageBelongsToProfileGallery(ctx context.Context, db QueryRower, dialect string, imageID int, profileID int) (bool, error)
- func InsertImage(ctx context.Context, db QueryExecRower, dialect string, imageType string, ...) (int, error)
- func InsertImageSize(ctx context.Context, db Execer, dialect string, size string, width int, ...) error
- func InsertLastSeenOnline(ctx context.Context, db Execer, dialect string, userID int, seenAt time.Time) error
- func InsertPasswordToken(ctx context.Context, db QueryExecRower, dialect string, userID int, ...) (int, error)
- func InsertProfile(ctx context.Context, db QueryExecRower, dialect string, userID int, bio string, ...) (int, error)
- func LinkProfilesAsFriends(ctx context.Context, db Execer, dialect string, profileID int, friendID int) error
- func MarkProfileFullyOnboardedByID(ctx context.Context, db Execer, dialect string, profileID int) error
- func MarkProfilePhoneVerifiedByID(ctx context.Context, db Execer, dialect string, profileID int) error
- func MarkUserVerifiedByUserID(ctx context.Context, db Execer, dialect string, userID int) error
- func RemoveSubscriptionBenefactorBySubscriptionAndProfile(ctx context.Context, db Execer, dialect string, subscriptionID int, ...) error
- func SetProfileImageID(ctx context.Context, db Execer, dialect string, profileID int, imageID int) error
- func UnlinkProfilesAsFriends(ctx context.Context, db Execer, dialect string, profileID int, friendID int) error
- func UpdateProfileBioByID(ctx context.Context, db Execer, dialect string, profileID int, bio string) error
- func UpdateProfileDetailsByID(ctx context.Context, db Execer, dialect string, profileID int, bio string, ...) error
- func UpdateProfilePhoneByID(ctx context.Context, db Execer, dialect string, profileID int, ...) error
- func UpdateUserDisplayNameByUserID(ctx context.Context, db Execer, dialect string, userID int, displayName string) error
- func UpdateUserPasswordHashByUserID(ctx context.Context, db Execer, dialect string, userID int, ...) error
- type AuthIdentity
- type AuthUserRecord
- type Execer
- type ProfileCoreRecord
- type ProfileFriendRecord
- type ProfilePhotoSizeRecord
- func GetImageStorageObjectsByImageID(ctx context.Context, db Queryer, dialect string, imageID int) ([]ProfilePhotoSizeRecord, error)
- func GetProfileImageByProfileID(ctx context.Context, db Queryer, dialect string, profileID int) ([]ProfilePhotoSizeRecord, error)
- func GetProfilePhotosByProfileID(ctx context.Context, db Queryer, dialect string, profileID int) ([]ProfilePhotoSizeRecord, error)
- type ProfileSettingsRecord
- type QueryExecRower
- type QueryRower
- type Queryer
- type SubscriptionBenefactorRecord
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AreProfilesFriends ¶
func DeleteImageByID ¶
func DeleteSubscriptionByID ¶
func DeleteUserByProfileID ¶
func GetPasswordTokenHash ¶
func InsertImage ¶
func InsertImageSize ¶
func InsertLastSeenOnline ¶
func InsertPasswordToken ¶
func InsertProfile ¶
func LinkProfilesAsFriends ¶
func SetProfileImageID ¶
func UnlinkProfilesAsFriends ¶
func UpdateProfileBioByID ¶
func UpdateProfilePhoneByID ¶
Types ¶
type AuthIdentity ¶
type AuthIdentity struct {
UserID int
UserName string
UserEmail string
HasProfile bool
ProfileID int
ProfileFullyOnboarded bool
}
func GetAuthIdentityByUserID ¶
func GetAuthIdentityByUserID( ctx context.Context, db QueryRower, dialect string, userID int, ) (*AuthIdentity, error)
type AuthUserRecord ¶
func GetAuthUserRecordByEmail ¶
func GetAuthUserRecordByEmail( ctx context.Context, db QueryRower, dialect string, email string, ) (*AuthUserRecord, error)
type Execer ¶
type Execer interface {
ExecContext(ctx context.Context, query string, args ...any) (sql.Result, error)
}
Execer is the minimal exec contract used by generated write helpers.
type ProfileCoreRecord ¶
type ProfileCoreRecord struct {
ProfileID int
Name string
Age sql.NullInt64
Bio sql.NullString
PhoneNumberE164 sql.NullString
CountryCode sql.NullString
}
func GetProfileCoreByID ¶
func GetProfileCoreByID( ctx context.Context, db QueryRower, dialect string, profileID int, ) (*ProfileCoreRecord, error)
type ProfileFriendRecord ¶
type ProfileFriendRecord struct {
ProfileID int
UserID int
Name string
Age sql.NullInt64
Bio sql.NullString
PhoneNumberE164 sql.NullString
CountryCode sql.NullString
}
func GetFriendsByProfileID ¶
type ProfilePhotoSizeRecord ¶
type ProfilePhotoSizeRecord struct {
ImageID int
Size string
Width int
Height int
ObjectKey string
}
type ProfileSettingsRecord ¶
type ProfileSettingsRecord struct {
ID int
Bio string
Birthdate sql.NullTime
CountryCode sql.NullString
PhoneNumberE164 sql.NullString
PhoneVerified bool
FullyOnboarded bool
}
func GetProfileSettingsByID ¶
func GetProfileSettingsByID( ctx context.Context, db QueryRower, dialect string, profileID int, ) (*ProfileSettingsRecord, error)
type QueryExecRower ¶
type QueryExecRower interface {
QueryRower
Execer
}
QueryExecRower is the minimal combined contract for read/write helpers that need both QueryRowContext and ExecContext support.
type QueryRower ¶
type QueryRower interface {
QueryRowContext(ctx context.Context, query string, args ...any) *sql.Row
}
QueryRower is the minimal query contract used by generated read helpers.
type SubscriptionBenefactorRecord ¶
func GetSubscriptionForBenefactorByProfileID ¶
func GetSubscriptionForBenefactorByProfileID( ctx context.Context, db QueryRower, dialect string, profileID int, ) (*SubscriptionBenefactorRecord, error)
Click to show internal directories.
Click to hide internal directories.